Enum simpath::PathError [−][src]
When validating a Simpath there can be the following types of PathErrors returned
Variants
DoesNotExist(String)The Path entry does not exist on the file system
CannotRead(String)The Path entry cannot be reads